@@ -31,6 +31,7 @@
 #include "latexila-build-tool.h"
 #include <string.h>
 #include <glib/gi18n.h>
+#include <tepl/tepl.h>
 #include "latexila-build-job.h"
 #include "latexila-build-view.h"
 #include "latexila-utils.h"
@@ -664,18 +665,18 @@ open_file (GTask *task)
 	filename = g_file_get_uri (data->file);
 	filename_for_display = g_file_get_parse_name (data->file);
 
-	shortname = latexila_utils_get_shortname (filename);
-	shortname_for_display = latexila_utils_get_shortname (filename_for_display);
+	shortname = tepl_utils_get_file_shortname (filename);
+	shortname_for_display = tepl_utils_get_file_shortname (filename_for_display);
 
 	if (strstr (file_to_open, "$filename") != NULL)
 	{
-		uri = latexila_utils_str_replace (file_to_open, "$filename", filename);
-		uri_for_display = latexila_utils_str_replace (file_to_open, "$filename", filename_for_display);
+		uri = tepl_utils_str_replace (file_to_open, "$filename", filename);
+		uri_for_display = tepl_utils_str_replace (file_to_open, "$filename", filename_for_display);
 	}
 	else if (strstr (file_to_open, "$shortname") != NULL)
 	{
-		uri = latexila_utils_str_replace (file_to_open, "$shortname", shortname);
-		uri_for_display = latexila_utils_str_replace (file_to_open, "$shortname", shortname_for_display);
+		uri = tepl_utils_str_replace (file_to_open, "$shortname", shortname);
+		uri_for_display = tepl_utils_str_replace (file_to_open, "$shortname", shortname_for_display);
 	}
 	else
 	{
