@@ -33,126 +33,13 @@
 #include "config.h"
 #include "latexila-utils.h"
 #include <string.h>
+#include <tepl/tepl.h>
 #include "latexila-synctex.h"
 
 #if HAVE_DCONF_MIGRATION
 #include "dh-dconf-migration.h"
 #endif
 
-static gint
-get_extension_position (const gchar *filename)
-{
-	const gchar *pos;
-	gint length;
-
-	if (filename == NULL)
-	{
-		return 0;
-	}
-
-	length = strlen (filename);
-	pos = filename + length;
-	g_assert (pos[0] == '\0');
-
-	while (TRUE)
-	{
-		pos = g_utf8_find_prev_char (filename, pos);
-
-		if (pos == NULL || pos[0] == '/')
-		{
-			break;
-		}
-
-		if (pos[0] == '.')
-		{
-			return pos - filename;
-		}
-	}
-
-	return length;
-}
-
-/**
- * latexila_utils_get_shortname:
- * @filename: a filename.
- *
- * Returns: the @filename without its extension. Free with g_free().
- */
-gchar *
-latexila_utils_get_shortname (const gchar *filename)
-{
-	return g_strndup (filename, get_extension_position (filename));
-}
-
-/**
- * latexila_utils_get_extension:
- * @filename: a filename.
- *
- * Returns: the @filename's extension with the dot, in lowercase. Free with
- * g_free().
- */
-gchar *
-latexila_utils_get_extension (const gchar *filename)
-{
-	gint pos = get_extension_position (filename);
-
-	return g_ascii_strdown (filename + pos, -1);
-}
-
-/**
- * latexila_utils_replace_home_dir_with_tilde:
- * @filename: the filename.
- *
- * Replaces the home directory with a tilde, if the home directory is present in
- * the @filename.
- *
- * This function comes from gedit.
- *
- * Returns: the new filename. Free with g_free().
- */
-gchar *
-latexila_utils_replace_home_dir_with_tilde (const gchar *filename)
-{
-	gchar *tmp;
-	gchar *home;
-
-	g_return_val_if_fail (filename != NULL, NULL);
-
-	/* Note that g_get_home_dir returns a const string */
-	tmp = (gchar *) g_get_home_dir ();
-
-	if (tmp == NULL)
-	{
-		return g_strdup (filename);
-	}
-
-	home = g_filename_to_utf8 (tmp, -1, NULL, NULL, NULL);
-	if (home == NULL)
-	{
-		return g_strdup (filename);
-	}
-
-	if (strcmp (filename, home) == 0)
-	{
-		g_free (home);
-		return g_strdup ("~");
-	}
-
-	tmp = home;
-	home = g_strdup_printf ("%s/", tmp);
-	g_free (tmp);
-
-	if (g_str_has_prefix (filename, home))
-	{
-		gchar *res = g_strdup_printf ("~/%s", filename + strlen (home));
-		g_free (home);
-		return res;
-	}
-
-	g_free (home);
-	return g_strdup (filename);
-}
-
 /**
  * latexila_utils_register_icons:
  *
@@ -204,42 +91,6 @@ latexila_utils_get_pixbuf_from_icon_name (const gchar *icon_name,
 	return pixbuf;
 }
 
-/**
- * latexila_utils_str_replace:
- * @string: a string
- * @search: the search string
- * @replacement: the replacement string
- *
- * Replaces all occurences of @search by @replacement.
- *
- * Returns: A newly allocated string with the replacements. Free with g_free().
- */
-gchar *
-latexila_utils_str_replace (const gchar *string,
-			    const gchar *search,
-			    const gchar *replacement)
-{
-	gchar **chunks;
-	gchar *ret;
-
-	g_return_val_if_fail (string != NULL, NULL);
-	g_return_val_if_fail (search != NULL, NULL);
-	g_return_val_if_fail (replacement != NULL, NULL);
-
-	chunks = g_strsplit (string, search, -1);
-	if (chunks != NULL && chunks[0] != NULL)
-	{
-		ret = g_strjoinv (replacement, chunks);
-	}
-	else
-	{
-		ret = g_strdup (string);
-	}
-
-	g_strfreev (chunks);
-	return ret;
-}
-
 /**
  * latexila_utils_file_query_exists_async:
  * @file: a #GFile.
@@ -359,7 +210,7 @@ latexila_utils_show_uri (GtkWidget    *widget,
 
 	if (gtk_show_uri_on_window (parent, uri, timestamp, error))
 	{
-		gchar *extension = latexila_utils_get_extension (uri);
+		gchar *extension = tepl_utils_get_file_extension (uri);
 
 		if (g_strcmp0 (extension, ".pdf") == 0 &&
 		    default_document_viewer_is_evince (uri))
@@ -567,7 +418,7 @@ migrate_latexila_to_gnome_latex_gsettings (void)
 		g_free (cur_latexila_key);
 	}
 
-	_dh_dconf_migration_free (migration);
+	_dh_dconf_migration_sync_and_free (migration);
 #else
 	g_warning ("LaTeXila -> GNOME LaTeX dconf migration not supported.");
 #endif
