@@ -26,12 +26,6 @@ G_BEGIN_DECLS
 
 /* File utilities */
 
-gchar *		latexila_utils_get_shortname			(const gchar *filename);
-
-gchar *		latexila_utils_get_extension			(const gchar *filename);
-
-gchar *		latexila_utils_replace_home_dir_with_tilde	(const gchar *filename);
-
 void		latexila_utils_file_query_exists_async		(GFile               *file,
 								 GCancellable        *cancellable,
 								 GAsyncReadyCallback  callback,
@@ -59,12 +53,6 @@ GtkWidget *	latexila_utils_join_widgets			(GtkWidget *widget_top,
 GdkPixbuf *	latexila_utils_get_pixbuf_from_icon_name	(const gchar *icon_name,
 								 GtkIconSize  icon_size);
 
-/* String utilities */
-
-gchar *		latexila_utils_str_replace			(const gchar *string,
-								 const gchar *search,
-								 const gchar *replacement);
-
 /* Others */
 
 void		latexila_utils_register_icons			(void);
